# -*- coding: utf-8 -*-
"""JSON Schemas."""

affiliation_record = {
    "title": "AffiliationRecord",
    "type": "object",
    "properties": {
        "id": {"type": "integer", "format": "int64"},
        "put-code": {"type": ["string", "null", "integer"]},
        "local-id": {"type": ["string", "null"]},
        "is-active": {"type": "boolean"},
        "email": {"type": ["string", "null"]},
        "first-name": {"type": ["string", "null"]},
        "last-name": {"type": ["string", "null"]},
        "role": {"type": ["string", "null"]},
        "organisation": {"type": ["string", "null"]},
        "department": {"type": ["string", "null"]},
        "city": {"type": ["string", "null"]},
        "state": {"type": ["string", "null"]},
        "country": {"type": ["string", "null"]},
        "disambiguated-id": {"type": ["string", "null"]},
        "disambiguated-source": {"type": ["string", "null"]},
        "affiliation-type": {"type": ["string", "null"]},
        "start-date": {"type": ["string", "null"]},
        "end-date": {"type": ["string", "null"]},
        "processed-at": {"type": ["string", "null"], "format": "date-time"},
        "status": {"type": ["string", "null"]},
        "url": {"type": ["string", "null"]},
        "visibility": {"type": ["string", "null"]},
        "display_index": {"type": ["string", "null"]},
        "orcid": {
            "type": ["string", "null"],
            "format": "^[0-9]{4}-?[0-9]{4}-?[0-9]{4}-?[0-9]{4}$",
        }
    },
    "required": ["email", "first-name", "last-name", "affiliation-type"]
}

affiliation_task = {
    "title": "AffiliationTask",
    "type": "object",
    "properties": {
        "id": {"type": "integer", "format": "int64"},
        "filename": {"type": ["string", "null"]},
        "task-type": {"type": ["string", "null"], "enum": ["AFFILIATION", "FUNDING", ]},
        "created-at": {"type": ["string", "null"], "format": "date-time"},
        "expires-at": {"type": ["string", "null"], "format": "date-time"},
        "completed-at": {"type": ["string", "null"], "format": "date-time"},
        "records": {
            "type": "array",
            "items": affiliation_record
        },
    },
    "required": ["records"]
}

hub_user = {
    "title": "HubUser",
    "type": "object",
    "properties": {
        "id": {"type": "integer", "format": "int64"},
        "name": {"type": ["string", "null"]},
        "orcid": {
            "type": ["string", "null"],
            "format": "^[0-9]{4}-?[0-9]{4}-?[0-9]{4}-?[0-9]{4}$",
        },
        "email": {"type": ["string", "null"], "format": ".{1,}@.{1,}"},
        "eppn": {"type": ["string", "null"]},
        "confirmed": {"type": ["boolean", "null"]},
        "created-at": {"type": ["string", "null"], "format": "date-time"},
        "updated-at": {"type": ["string", "null"], "format": "date-time"},
        "completed-at": {"type": ["string", "null"], "format": "date-time"},
    },
    "anyOf": [{"required": ["email"]}, {"required": ["orcid"]}]
}


other_id_record = {
    "title": "OtherIdRecord",
    "type": "object",
    "properties": {
        "id": {"type": ["integer", "null"]},
        "put-code": {"type": ["string", "null", "integer"]},
        "is-active": {"type": "boolean"},
        "email": {"type": ["string", "null"]},
        "first-name": {"type": ["string", "null"]},
        "last-name": {"type": ["string", "null"]},
        "type": {"type": ["string", "null"]},
        "value": {"type": ["string", "null"]},
        "url": {"type": ["string", "null"]},
        "relationship": {"type": ["string", "null"]},
        "display-index": {"type": ["string", "null", "integer"]},
        "visibility": {"type": ["string", "null"]},
        "processed-at": {"type": ["string", "null"], "format": "date-time"},
        "status": {"type": ["string", "null"]},
        "orcid": {
            "type": ["string", "null"],
            "format": "^[0-9]{4}-?[0-9]{4}-?[0-9]{4}-?[0-9]{4}$",
        }
    },
    "anyOf": [
        {
            "required": ["type", "value", "url", "relationship", "email"]
        },
        {
            "required": ["type", "value", "url", "relationship", "orcid"]
        },
        {
            "required": ["external-id-type", "external-id-value", "external-id-url", "external-id-relationship",
                         "email"]
        },
        {
            "required": ["external-id-type", "external-id-value", "external-id-url", "external-id-relationship",
                         "orcid"]
        }
    ]
}

other_id_record_list = {
    "type": "array",
    "items": other_id_record
}

other_id_task = {
    "title": "OtherIDTask",
    "type": "object",
    "properties": {
        "id": {"type": "integer", "format": "int64"},
        "filename": {"type": ["string", "null"]},
        "task-type": {"type": ["string", "null"], "enum": ["OTHER_ID", "OTHER ID", ]},
        "created-at": {"type": ["string", "null"], "format": "date-time"},
        "updated-at": {"type": ["string", "null"], "format": "date-time"},
        "expires-at": {"type": ["string", "null"], "format": "date-time"},
        "completed-at": {"type": ["string", "null"], "format": "date-time"},
        "records": other_id_record_list,
    },
    "required": ["records"]
}

other_name_keyword_record = {
    "title": "OtherNameRecord",
    "type": "object",
    "properties": {
        "id": {"type": ["integer", "null"]},
        "put-code": {"type": ["string", "null", "integer"]},
        "is-active": {"type": "boolean"},
        "email": {"type": ["string", "null"]},
        "first-name": {"type": ["string", "null"]},
        "last-name": {"type": ["string", "null"]},
        "content": {"type": ["string", "null"]},
        "display-index": {"type": ["string", "null", "integer"]},
        "visibility": {"type": ["string", "null"]},
        "processed-at": {"type": ["string", "null"], "format": "date-time"},
        "status": {"type": ["string", "null"]},
        "orcid": {
            "type": ["string", "null"],
            "format": "^[0-9]{4}-?[0-9]{4}-?[0-9]{4}-?[0-9]{4}$",
        }
    },
    "anyOf": [
        {
            "required": ["content", "email"]
        },
        {
            "required": ["content", "orcid"]
        }
    ]
}

other_name_keyword_record_list = {
    "type": "array",
    "items": other_name_keyword_record,
}

other_name_keyword_task = {
    "title": "OtherNameTask",
    "type": "object",
    "properties": {
        "id": {"type": "integer", "format": "int64"},
        "filename": {"type": ["string", "null"]},
        "task-type": {"type": ["string", "null"], "enum": ["OTHER_NAME", "OTHER NAME", "KEYWORD"]},
        "created-at": {"type": ["string", "null"], "format": "date-time"},
        "updated-at": {"type": ["string", "null"], "format": "date-time"},
        "expires-at": {"type": ["string", "null"], "format": "date-time"},
        "completed-at": {"type": ["string", "null"], "format": "date-time"},
        "records": other_name_keyword_record_list,
    },
    "required": ["records"]
}

property_record = {
    "title": "PropertyRecord",
    "type": "object",
    "properties": {
        "id": {"type": ["integer", "null"]},
        "type": {
            "type": ["string", "null", "integer"],
            "enum": ["URL", "NAME", "KEYWORD", "COUNTRY", "url", "name", "keyword", "country", None]
        },
        "put-code": {"type": ["string", "null", "integer"]},
        "is-active": {"type": "boolean"},
        "email": {"type": ["string", "null"]},
        "first-name": {"type": ["string", "null"]},
        "last-name": {"type": ["string", "null"]},
        "name": {"type": ["string", "null"]},
        "value": {"type": ["string", "null"]},
        "content": {"type": ["string", "null"]},
        "display-index": {"type": ["string", "null", "integer"]},
        "visibility": {"type": ["string", "null"]},
        "processed-at": {"type": ["string", "null"], "format": "date-time"},
        "status": {"type": ["string", "null"]},
        "orcid": {
            "type": ["string", "null"],
            "format": "^[0-9]{4}-?[0-9]{4}-?[0-9]{4}-?[0-9]{4}$",
        }
    },
    "anyOf": [
        {
            "required": ["url-name", "url-value", "email"]
        },
        {
            "required": ["url-name", "url-value", "orcid"]
        },
        {
            "required": ["type", "value", "email"]
        },
        {
            "required": ["type", "value", "orcid"]
        },
        {
            "required": ["content", "email"]
        },
        {
            "required": ["content", "orcid"]
        },
        {
            "required": ["name", "value", "email"]
        },
        {
            "required": ["name", "value", "orcid"]
        },
        {
            "required": ["country", "email"]
        },
        {
            "required": ["country", "orcid"]
        },
    ]
}

property_record_list = {
    "type": "array",
    "items": property_record,
}

property_task = {
    "title": "OtherNameTask",
    "type": "object",
    "properties": {
        "id": {"type": "integer", "format": "int64"},
        "filename": {"type": ["string", "null"]},
        "task-type": {
            "type": ["string", "null"],
            "enum": ["PROPERTY", "OTHER_NAME", "OTHER NAME", "KEYWORD"]
        },
        "created-at": {"type": ["string", "null"], "format": "date-time"},
        "updated-at": {"type": ["string", "null"], "format": "date-time"},
        "expires-at": {"type": ["string", "null"], "format": "date-time"},
        "completed-at": {"type": ["string", "null"], "format": "date-time"},
        "records": property_record_list,
    },
    "required": ["records"]
}



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.disambiguated_organization_v30_rc1 import DisambiguatedOrganizationV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.organization_address_v30_rc1 import OrganizationAddressV30Rc1  # noqa: F401,E501


class OrganizationV30Rc1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'address': 'OrganizationAddressV30Rc1',
        'disambiguated_organization': 'DisambiguatedOrganizationV30Rc1'
    }

    attribute_map = {
        'name': 'name',
        'address': 'address',
        'disambiguated_organization': 'disambiguated-organization'
    }

    def __init__(self, name=None, address=None, disambiguated_organization=None):  # noqa: E501
        """OrganizationV30Rc1 - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._address = None
        self._disambiguated_organization = None
        self.discriminator = None
        self.name = name
        self.address = address
        if disambiguated_organization is not None:
            self.disambiguated_organization = disambiguated_organization

    @property
    def name(self):
        """Gets the name of this OrganizationV30Rc1.  # noqa: E501


        :return: The name of this OrganizationV30Rc1.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrganizationV30Rc1.


        :param name: The name of this OrganizationV30Rc1.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def address(self):
        """Gets the address of this OrganizationV30Rc1.  # noqa: E501


        :return: The address of this OrganizationV30Rc1.  # noqa: E501
        :rtype: OrganizationAddressV30Rc1
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this OrganizationV30Rc1.


        :param address: The address of this OrganizationV30Rc1.  # noqa: E501
        :type: OrganizationAddressV30Rc1
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def disambiguated_organization(self):
        """Gets the disambiguated_organization of this OrganizationV30Rc1.  # noqa: E501


        :return: The disambiguated_organization of this OrganizationV30Rc1.  # noqa: E501
        :rtype: DisambiguatedOrganizationV30Rc1
        """
        return self._disambiguated_organization

    @disambiguated_organization.setter
    def disambiguated_organization(self, disambiguated_organization):
        """Sets the disambiguated_organization of this OrganizationV30Rc1.


        :param disambiguated_organization: The disambiguated_organization of this OrganizationV30Rc1.  # noqa: E501
        :type: DisambiguatedOrganizationV30Rc1
        """

        self._disambiguated_organization = disambiguated_organization

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrganizationV30Rc1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationV30Rc1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.distinctions_v30_rc1 import DistinctionsV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.educations_summary_v30_rc1 import EducationsSummaryV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.employments_summary_v30_rc1 import EmploymentsSummaryV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.fundings_v30_rc1 import FundingsV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.invited_positions_v30_rc1 import InvitedPositionsV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.last_modified_date_v30_rc1 import LastModifiedDateV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.memberships_v30_rc1 import MembershipsV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.peer_reviews_v30_rc1 import PeerReviewsV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.qualifications_v30_rc1 import QualificationsV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.research_resources_v30_rc1 import ResearchResourcesV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.services_v30_rc1 import ServicesV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.works_summary_v30_rc1 import WorksSummaryV30Rc1  # noqa: F401,E501


class ActivitiesSummaryV30Rc1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'last_modified_date': 'LastModifiedDateV30Rc1',
        'distinctions': 'DistinctionsV30Rc1',
        'educations': 'EducationsSummaryV30Rc1',
        'employments': 'EmploymentsSummaryV30Rc1',
        'fundings': 'FundingsV30Rc1',
        'invited_positions': 'InvitedPositionsV30Rc1',
        'memberships': 'MembershipsV30Rc1',
        'peer_reviews': 'PeerReviewsV30Rc1',
        'qualifications': 'QualificationsV30Rc1',
        'research_resources': 'ResearchResourcesV30Rc1',
        'services': 'ServicesV30Rc1',
        'works': 'WorksSummaryV30Rc1',
        'path': 'str'
    }

    attribute_map = {
        'last_modified_date': 'last-modified-date',
        'distinctions': 'distinctions',
        'educations': 'educations',
        'employments': 'employments',
        'fundings': 'fundings',
        'invited_positions': 'invited-positions',
        'memberships': 'memberships',
        'peer_reviews': 'peer-reviews',
        'qualifications': 'qualifications',
        'research_resources': 'research-resources',
        'services': 'services',
        'works': 'works',
        'path': 'path'
    }

    def __init__(self, last_modified_date=None, distinctions=None, educations=None, employments=None, fundings=None, invited_positions=None, memberships=None, peer_reviews=None, qualifications=None, research_resources=None, services=None, works=None, path=None):  # noqa: E501
        """ActivitiesSummaryV30Rc1 - a model defined in Swagger"""  # noqa: E501
        self._last_modified_date = None
        self._distinctions = None
        self._educations = None
        self._employments = None
        self._fundings = None
        self._invited_positions = None
        self._memberships = None
        self._peer_reviews = None
        self._qualifications = None
        self._research_resources = None
        self._services = None
        self._works = None
        self._path = None
        self.discriminator = None
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if distinctions is not None:
            self.distinctions = distinctions
        if educations is not None:
            self.educations = educations
        if employments is not None:
            self.employments = employments
        if fundings is not None:
            self.fundings = fundings
        if invited_positions is not None:
            self.invited_positions = invited_positions
        if memberships is not None:
            self.memberships = memberships
        if peer_reviews is not None:
            self.peer_reviews = peer_reviews
        if qualifications is not None:
            self.qualifications = qualifications
        if research_resources is not None:
            self.research_resources = research_resources
        if services is not None:
            self.services = services
        if works is not None:
            self.works = works
        if path is not None:
            self.path = path

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The last_modified_date of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: LastModifiedDateV30Rc1
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this ActivitiesSummaryV30Rc1.


        :param last_modified_date: The last_modified_date of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: LastModifiedDateV30Rc1
        """

        self._last_modified_date = last_modified_date

    @property
    def distinctions(self):
        """Gets the distinctions of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The distinctions of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: DistinctionsV30Rc1
        """
        return self._distinctions

    @distinctions.setter
    def distinctions(self, distinctions):
        """Sets the distinctions of this ActivitiesSummaryV30Rc1.


        :param distinctions: The distinctions of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: DistinctionsV30Rc1
        """

        self._distinctions = distinctions

    @property
    def educations(self):
        """Gets the educations of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The educations of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: EducationsSummaryV30Rc1
        """
        return self._educations

    @educations.setter
    def educations(self, educations):
        """Sets the educations of this ActivitiesSummaryV30Rc1.


        :param educations: The educations of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: EducationsSummaryV30Rc1
        """

        self._educations = educations

    @property
    def employments(self):
        """Gets the employments of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The employments of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: EmploymentsSummaryV30Rc1
        """
        return self._employments

    @employments.setter
    def employments(self, employments):
        """Sets the employments of this ActivitiesSummaryV30Rc1.


        :param employments: The employments of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: EmploymentsSummaryV30Rc1
        """

        self._employments = employments

    @property
    def fundings(self):
        """Gets the fundings of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The fundings of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: FundingsV30Rc1
        """
        return self._fundings

    @fundings.setter
    def fundings(self, fundings):
        """Sets the fundings of this ActivitiesSummaryV30Rc1.


        :param fundings: The fundings of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: FundingsV30Rc1
        """

        self._fundings = fundings

    @property
    def invited_positions(self):
        """Gets the invited_positions of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The invited_positions of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: InvitedPositionsV30Rc1
        """
        return self._invited_positions

    @invited_positions.setter
    def invited_positions(self, invited_positions):
        """Sets the invited_positions of this ActivitiesSummaryV30Rc1.


        :param invited_positions: The invited_positions of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: InvitedPositionsV30Rc1
        """

        self._invited_positions = invited_positions

    @property
    def memberships(self):
        """Gets the memberships of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The memberships of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: MembershipsV30Rc1
        """
        return self._memberships

    @memberships.setter
    def memberships(self, memberships):
        """Sets the memberships of this ActivitiesSummaryV30Rc1.


        :param memberships: The memberships of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: MembershipsV30Rc1
        """

        self._memberships = memberships

    @property
    def peer_reviews(self):
        """Gets the peer_reviews of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The peer_reviews of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: PeerReviewsV30Rc1
        """
        return self._peer_reviews

    @peer_reviews.setter
    def peer_reviews(self, peer_reviews):
        """Sets the peer_reviews of this ActivitiesSummaryV30Rc1.


        :param peer_reviews: The peer_reviews of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: PeerReviewsV30Rc1
        """

        self._peer_reviews = peer_reviews

    @property
    def qualifications(self):
        """Gets the qualifications of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The qualifications of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: QualificationsV30Rc1
        """
        return self._qualifications

    @qualifications.setter
    def qualifications(self, qualifications):
        """Sets the qualifications of this ActivitiesSummaryV30Rc1.


        :param qualifications: The qualifications of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: QualificationsV30Rc1
        """

        self._qualifications = qualifications

    @property
    def research_resources(self):
        """Gets the research_resources of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The research_resources of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: ResearchResourcesV30Rc1
        """
        return self._research_resources

    @research_resources.setter
    def research_resources(self, research_resources):
        """Sets the research_resources of this ActivitiesSummaryV30Rc1.


        :param research_resources: The research_resources of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: ResearchResourcesV30Rc1
        """

        self._research_resources = research_resources

    @property
    def services(self):
        """Gets the services of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The services of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: ServicesV30Rc1
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this ActivitiesSummaryV30Rc1.


        :param services: The services of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: ServicesV30Rc1
        """

        self._services = services

    @property
    def works(self):
        """Gets the works of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The works of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: WorksSummaryV30Rc1
        """
        return self._works

    @works.setter
    def works(self, works):
        """Sets the works of this ActivitiesSummaryV30Rc1.


        :param works: The works of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: WorksSummaryV30Rc1
        """

        self._works = works

    @property
    def path(self):
        """Gets the path of this ActivitiesSummaryV30Rc1.  # noqa: E501


        :return: The path of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ActivitiesSummaryV30Rc1.


        :param path: The path of this ActivitiesSummaryV30Rc1.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivitiesSummaryV30Rc1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivitiesSummaryV30Rc1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from orcid_api_v3.api.development_member_api_v3_0_api import DevelopmentMemberAPIV30Api
from orcid_api_v3.api.development_member_api_v3_0_rc1_api import DevelopmentMemberAPIV30Rc1Api
from orcid_api_v3.api.development_member_api_v3_0_rc2_api import DevelopmentMemberAPIV30Rc2Api
from orcid_api_v3.api.member_api_v2_0_api import MemberAPIV20Api
from orcid_api_v3.api.member_api_v2_1_api import MemberAPIV21Api



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.external_i_ds_v30_rc2 import ExternalIDsV30Rc2  # noqa: F401,E501
from orcid_api_v3.models.fuzzy_date_v30_rc2 import FuzzyDateV30Rc2  # noqa: F401,E501
from orcid_api_v3.models.research_resource_hosts_v30_rc2 import ResearchResourceHostsV30Rc2  # noqa: F401,E501
from orcid_api_v3.models.research_resource_title_v30_rc2 import ResearchResourceTitleV30Rc2  # noqa: F401,E501
from orcid_api_v3.models.url_v30_rc2 import UrlV30Rc2  # noqa: F401,E501


class ResearchResourceProposalV30Rc2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'ResearchResourceTitleV30Rc2',
        'hosts': 'ResearchResourceHostsV30Rc2',
        'external_ids': 'ExternalIDsV30Rc2',
        'start_date': 'FuzzyDateV30Rc2',
        'end_date': 'FuzzyDateV30Rc2',
        'url': 'UrlV30Rc2'
    }

    attribute_map = {
        'title': 'title',
        'hosts': 'hosts',
        'external_ids': 'external-ids',
        'start_date': 'start-date',
        'end_date': 'end-date',
        'url': 'url'
    }

    def __init__(self, title=None, hosts=None, external_ids=None, start_date=None, end_date=None, url=None):  # noqa: E501
        """ResearchResourceProposalV30Rc2 - a model defined in Swagger"""  # noqa: E501
        self._title = None
        self._hosts = None
        self._external_ids = None
        self._start_date = None
        self._end_date = None
        self._url = None
        self.discriminator = None
        if title is not None:
            self.title = title
        if hosts is not None:
            self.hosts = hosts
        if external_ids is not None:
            self.external_ids = external_ids
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if url is not None:
            self.url = url

    @property
    def title(self):
        """Gets the title of this ResearchResourceProposalV30Rc2.  # noqa: E501


        :return: The title of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :rtype: ResearchResourceTitleV30Rc2
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ResearchResourceProposalV30Rc2.


        :param title: The title of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :type: ResearchResourceTitleV30Rc2
        """

        self._title = title

    @property
    def hosts(self):
        """Gets the hosts of this ResearchResourceProposalV30Rc2.  # noqa: E501


        :return: The hosts of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :rtype: ResearchResourceHostsV30Rc2
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this ResearchResourceProposalV30Rc2.


        :param hosts: The hosts of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :type: ResearchResourceHostsV30Rc2
        """

        self._hosts = hosts

    @property
    def external_ids(self):
        """Gets the external_ids of this ResearchResourceProposalV30Rc2.  # noqa: E501


        :return: The external_ids of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :rtype: ExternalIDsV30Rc2
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """Sets the external_ids of this ResearchResourceProposalV30Rc2.


        :param external_ids: The external_ids of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :type: ExternalIDsV30Rc2
        """

        self._external_ids = external_ids

    @property
    def start_date(self):
        """Gets the start_date of this ResearchResourceProposalV30Rc2.  # noqa: E501


        :return: The start_date of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :rtype: FuzzyDateV30Rc2
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ResearchResourceProposalV30Rc2.


        :param start_date: The start_date of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :type: FuzzyDateV30Rc2
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ResearchResourceProposalV30Rc2.  # noqa: E501


        :return: The end_date of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :rtype: FuzzyDateV30Rc2
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ResearchResourceProposalV30Rc2.


        :param end_date: The end_date of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :type: FuzzyDateV30Rc2
        """

        self._end_date = end_date

    @property
    def url(self):
        """Gets the url of this ResearchResourceProposalV30Rc2.  # noqa: E501


        :return: The url of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :rtype: UrlV30Rc2
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ResearchResourceProposalV30Rc2.


        :param url: The url of this ResearchResourceProposalV30Rc2.  # noqa: E501
        :type: UrlV30Rc2
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResearchResourceProposalV30Rc2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResearchResourceProposalV30Rc2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.amount_v20 import AmountV20  # noqa: F401,E501
from orcid_api_v3.models.created_date_v20 import CreatedDateV20  # noqa: F401,E501
from orcid_api_v3.models.external_i_ds_v20 import ExternalIDsV20  # noqa: F401,E501
from orcid_api_v3.models.funding_contributors_v20 import FundingContributorsV20  # noqa: F401,E501
from orcid_api_v3.models.funding_title_v20 import FundingTitleV20  # noqa: F401,E501
from orcid_api_v3.models.fuzzy_date_v20 import FuzzyDateV20  # noqa: F401,E501
from orcid_api_v3.models.last_modified_date_v20 import LastModifiedDateV20  # noqa: F401,E501
from orcid_api_v3.models.organization_defined_funding_sub_type_v20 import OrganizationDefinedFundingSubTypeV20  # noqa: F401,E501
from orcid_api_v3.models.organization_v20 import OrganizationV20  # noqa: F401,E501
from orcid_api_v3.models.source_v20 import SourceV20  # noqa: F401,E501
from orcid_api_v3.models.url_v20 import UrlV20  # noqa: F401,E501


class FundingV20(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date': 'CreatedDateV20',
        'last_modified_date': 'LastModifiedDateV20',
        'source': 'SourceV20',
        'put_code': 'int',
        'path': 'str',
        'type': 'str',
        'organization_defined_type': 'OrganizationDefinedFundingSubTypeV20',
        'title': 'FundingTitleV20',
        'short_description': 'str',
        'amount': 'AmountV20',
        'url': 'UrlV20',
        'start_date': 'FuzzyDateV20',
        'end_date': 'FuzzyDateV20',
        'external_ids': 'ExternalIDsV20',
        'contributors': 'FundingContributorsV20',
        'organization': 'OrganizationV20',
        'visibility': 'str'
    }

    attribute_map = {
        'created_date': 'created-date',
        'last_modified_date': 'last-modified-date',
        'source': 'source',
        'put_code': 'put-code',
        'path': 'path',
        'type': 'type',
        'organization_defined_type': 'organization-defined-type',
        'title': 'title',
        'short_description': 'short-description',
        'amount': 'amount',
        'url': 'url',
        'start_date': 'start-date',
        'end_date': 'end-date',
        'external_ids': 'external-ids',
        'contributors': 'contributors',
        'organization': 'organization',
        'visibility': 'visibility'
    }

    def __init__(self, created_date=None, last_modified_date=None, source=None, put_code=None, path=None, type=None, organization_defined_type=None, title=None, short_description=None, amount=None, url=None, start_date=None, end_date=None, external_ids=None, contributors=None, organization=None, visibility=None):  # noqa: E501
        """FundingV20 - a model defined in Swagger"""  # noqa: E501
        self._created_date = None
        self._last_modified_date = None
        self._source = None
        self._put_code = None
        self._path = None
        self._type = None
        self._organization_defined_type = None
        self._title = None
        self._short_description = None
        self._amount = None
        self._url = None
        self._start_date = None
        self._end_date = None
        self._external_ids = None
        self._contributors = None
        self._organization = None
        self._visibility = None
        self.discriminator = None
        if created_date is not None:
            self.created_date = created_date
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if source is not None:
            self.source = source
        if put_code is not None:
            self.put_code = put_code
        if path is not None:
            self.path = path
        self.type = type
        if organization_defined_type is not None:
            self.organization_defined_type = organization_defined_type
        self.title = title
        if short_description is not None:
            self.short_description = short_description
        if amount is not None:
            self.amount = amount
        if url is not None:
            self.url = url
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if external_ids is not None:
            self.external_ids = external_ids
        if contributors is not None:
            self.contributors = contributors
        self.organization = organization
        if visibility is not None:
            self.visibility = visibility

    @property
    def created_date(self):
        """Gets the created_date of this FundingV20.  # noqa: E501


        :return: The created_date of this FundingV20.  # noqa: E501
        :rtype: CreatedDateV20
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this FundingV20.


        :param created_date: The created_date of this FundingV20.  # noqa: E501
        :type: CreatedDateV20
        """

        self._created_date = created_date

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this FundingV20.  # noqa: E501


        :return: The last_modified_date of this FundingV20.  # noqa: E501
        :rtype: LastModifiedDateV20
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this FundingV20.


        :param last_modified_date: The last_modified_date of this FundingV20.  # noqa: E501
        :type: LastModifiedDateV20
        """

        self._last_modified_date = last_modified_date

    @property
    def source(self):
        """Gets the source of this FundingV20.  # noqa: E501


        :return: The source of this FundingV20.  # noqa: E501
        :rtype: SourceV20
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this FundingV20.


        :param source: The source of this FundingV20.  # noqa: E501
        :type: SourceV20
        """

        self._source = source

    @property
    def put_code(self):
        """Gets the put_code of this FundingV20.  # noqa: E501


        :return: The put_code of this FundingV20.  # noqa: E501
        :rtype: int
        """
        return self._put_code

    @put_code.setter
    def put_code(self, put_code):
        """Sets the put_code of this FundingV20.


        :param put_code: The put_code of this FundingV20.  # noqa: E501
        :type: int
        """

        self._put_code = put_code

    @property
    def path(self):
        """Gets the path of this FundingV20.  # noqa: E501


        :return: The path of this FundingV20.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this FundingV20.


        :param path: The path of this FundingV20.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def type(self):
        """Gets the type of this FundingV20.  # noqa: E501


        :return: The type of this FundingV20.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FundingV20.


        :param type: The type of this FundingV20.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["GRANT", "CONTRACT", "AWARD", "SALARY_AWARD"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def organization_defined_type(self):
        """Gets the organization_defined_type of this FundingV20.  # noqa: E501


        :return: The organization_defined_type of this FundingV20.  # noqa: E501
        :rtype: OrganizationDefinedFundingSubTypeV20
        """
        return self._organization_defined_type

    @organization_defined_type.setter
    def organization_defined_type(self, organization_defined_type):
        """Sets the organization_defined_type of this FundingV20.


        :param organization_defined_type: The organization_defined_type of this FundingV20.  # noqa: E501
        :type: OrganizationDefinedFundingSubTypeV20
        """

        self._organization_defined_type = organization_defined_type

    @property
    def title(self):
        """Gets the title of this FundingV20.  # noqa: E501


        :return: The title of this FundingV20.  # noqa: E501
        :rtype: FundingTitleV20
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this FundingV20.


        :param title: The title of this FundingV20.  # noqa: E501
        :type: FundingTitleV20
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def short_description(self):
        """Gets the short_description of this FundingV20.  # noqa: E501


        :return: The short_description of this FundingV20.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this FundingV20.


        :param short_description: The short_description of this FundingV20.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def amount(self):
        """Gets the amount of this FundingV20.  # noqa: E501


        :return: The amount of this FundingV20.  # noqa: E501
        :rtype: AmountV20
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this FundingV20.


        :param amount: The amount of this FundingV20.  # noqa: E501
        :type: AmountV20
        """

        self._amount = amount

    @property
    def url(self):
        """Gets the url of this FundingV20.  # noqa: E501


        :return: The url of this FundingV20.  # noqa: E501
        :rtype: UrlV20
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this FundingV20.


        :param url: The url of this FundingV20.  # noqa: E501
        :type: UrlV20
        """

        self._url = url

    @property
    def start_date(self):
        """Gets the start_date of this FundingV20.  # noqa: E501


        :return: The start_date of this FundingV20.  # noqa: E501
        :rtype: FuzzyDateV20
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this FundingV20.


        :param start_date: The start_date of this FundingV20.  # noqa: E501
        :type: FuzzyDateV20
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this FundingV20.  # noqa: E501


        :return: The end_date of this FundingV20.  # noqa: E501
        :rtype: FuzzyDateV20
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this FundingV20.


        :param end_date: The end_date of this FundingV20.  # noqa: E501
        :type: FuzzyDateV20
        """

        self._end_date = end_date

    @property
    def external_ids(self):
        """Gets the external_ids of this FundingV20.  # noqa: E501


        :return: The external_ids of this FundingV20.  # noqa: E501
        :rtype: ExternalIDsV20
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """Sets the external_ids of this FundingV20.


        :param external_ids: The external_ids of this FundingV20.  # noqa: E501
        :type: ExternalIDsV20
        """

        self._external_ids = external_ids

    @property
    def contributors(self):
        """Gets the contributors of this FundingV20.  # noqa: E501


        :return: The contributors of this FundingV20.  # noqa: E501
        :rtype: FundingContributorsV20
        """
        return self._contributors

    @contributors.setter
    def contributors(self, contributors):
        """Sets the contributors of this FundingV20.


        :param contributors: The contributors of this FundingV20.  # noqa: E501
        :type: FundingContributorsV20
        """

        self._contributors = contributors

    @property
    def organization(self):
        """Gets the organization of this FundingV20.  # noqa: E501


        :return: The organization of this FundingV20.  # noqa: E501
        :rtype: OrganizationV20
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this FundingV20.


        :param organization: The organization of this FundingV20.  # noqa: E501
        :type: OrganizationV20
        """
        if organization is None:
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def visibility(self):
        """Gets the visibility of this FundingV20.  # noqa: E501


        :return: The visibility of this FundingV20.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this FundingV20.


        :param visibility: The visibility of this FundingV20.  # noqa: E501
        :type: str
        """
        allowed_values = ["LIMITED", "REGISTERED_ONLY", "PUBLIC", "PRIVATE"]  # noqa: E501
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"  # noqa: E501
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FundingV20, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FundingV20):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# -*- coding: utf-8 -*-
"""Tests for forms and WTForms extensions."""

# noqa: D103
from unittest.mock import MagicMock

import pytest
from wtforms import Form, StringField

from orcid_hub.forms import validate_orcid_id_field  # noqa: E128
from orcid_hub.forms import BitmapMultipleValueField, CountrySelectField, PartialDate, PartialDateField
from orcid_hub.models import PartialDate as PartialDateDbField


def test_partial_date_widget():  # noqa
    assert '<option selected value="1995">1995</option>' in PartialDate()(
        MagicMock(data=PartialDateDbField(1995)))

    field = MagicMock(label="LABEL", id="ID", data=PartialDateDbField(2017, 5, 13))
    field.name = "NAME"
    pd = PartialDate()(field)
    assert '<option selected value="2017">2017</option>' in pd
    assert '<option selected value="5">05</option>' in pd
    assert '<option selected value="13">13</option><option value="14">14</option>' in pd
    assert '"NAME:year"' in pd
    assert '"NAME:month"' in pd
    assert '"NAME:day"' in pd


@pytest.fixture
def test_form():  # noqa
    class F(Form):
        pdf1 = PartialDateField("f1", default=PartialDateDbField(1995), id="test-id-1")
        pdf2 = PartialDateField("f2", default=PartialDateDbField(2017, 5, 13), id="test-id-2")
        pdf3 = PartialDateField("f3")
        csf1 = CountrySelectField()
        csf2 = CountrySelectField(label="Select Country")
        bmvf1 = BitmapMultipleValueField(choices=[
            (
                1,
                "one",
            ),
            (
                2,
                "two",
            ),
            (
                4,
                "four",
            ),
        ])
        bmvf2 = BitmapMultipleValueField(
            choices=[
                (
                    1,
                    "one",
                ),
                (
                    2,
                    "two",
                ),
                (
                    4,
                    "four",
                ),
            ], )
        bmvf2.is_bitmap_value = False

    return F


def test_partial_date_field_defaults(test_form):  # noqa

    tf = test_form()
    assert tf.pdf1.data == PartialDateDbField(1995)
    assert tf.pdf2.data == PartialDateDbField(2017, 5, 13)
    assert tf.pdf1.label.text == "f1"


class DummyPostData(dict):  # noqa
    def __init__(self, data):  # noqa
        super().__init__()
        self.update(data)

    def getlist(self, key):  # noqa
        v = self[key]
        if not isinstance(v, (list, tuple)):
            v = [v]
        return v


def test_partial_date_field_with_data(test_form):  # noqa

    tf = test_form(DummyPostData({"pdf1:year": "2000", "pdf1:month": "1", "pdf1:day": "31"}))
    pdf1 = tf.pdf1()

    assert '<option selected value="31">' in pdf1
    assert '<option value="2001">2001</option><option selected value="2000">2000</option>' in pdf1
    assert '<option value="">Month</option><option selected value="1">01</option><option value="2">' in pdf1


def test_partial_date_field_errors(test_form):  # noqa

    tf = test_form(
        DummyPostData({
            "pdf1:year": "ERROR",
            "pdf1:month": "ERROR",
            "pdf1:day": "ERROR"
        }))
    tf.validate()
    assert len(tf.pdf1.process_errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "2001", "pdf1:month": "", "pdf1:day": "31"}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "", "pdf1:month": "12", "pdf1:day": "31"}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "2001", "pdf1:month": "13", "pdf1:day": ""}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "2001", "pdf1:month": "-1", "pdf1:day": ""}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "1995", "pdf1:month": "2", "pdf1:day": "29"}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "1996", "pdf1:month": "2", "pdf1:day": "29"}))
    tf.validate()
    assert not tf.pdf1.errors

    tf = test_form(DummyPostData({"pdf1:year": "1994", "pdf1:month": "2", "pdf1:day": "30"}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0

    tf = test_form(DummyPostData({"pdf1:year": "1994", "pdf1:month": "4", "pdf1:day": "31"}))
    tf.validate()
    assert len(tf.pdf1.errors) > 0


def test_partial_date_field_with_filter(test_form):  # noqa

    test_form.pdf = PartialDateField(
        "f", filters=[lambda pd: PartialDateDbField(pd.year + 1, pd.month + 1, pd.day + 1)])

    tf = test_form(DummyPostData({"pdf:year": "2012", "pdf:month": "4", "pdf:day": "12"}))
    pdf = tf.pdf()

    assert '<option selected value="13">' in pdf
    assert '<option selected value="2013">' in pdf
    assert '<option selected value="5">' in pdf
    assert len(tf.pdf1.process_errors) == 0

    def failing_filter(*args, **kwargs):
        raise ValueError("ERROR!!!")

    test_form.pdf = PartialDateField("f", filters=[failing_filter])
    tf = test_form(DummyPostData({"pdf:year": "2012", "pdf:month": "4", "pdf:day": "12"}))
    assert len(tf.pdf.process_errors) > 0
    assert "ERROR!!!" in tf.pdf.process_errors


def test_partial_date_field_with_obj(test_form):  # noqa

    tf = test_form(None, obj=MagicMock(pdf1=PartialDateDbField(2017, 1, 13)))
    pdf1 = tf.pdf1()

    assert '<option selected value="13">' in pdf1
    assert '<option selected value="2017">2017</option>' in pdf1
    assert '<option value="">Month</option><option selected value="1">01</option><option value="2">' in pdf1

    tf = test_form(None, obj=MagicMock(pdf3=PartialDateDbField(2017)))
    pdf3 = tf.pdf3()

    assert '<option selected value="">' in pdf3
    assert '<option selected value="2017">2017</option>' in pdf3
    assert '<option selected value="">Month</option><option value="1">01</option><option value="2">' in pdf3


def test_partial_date_field_with_data_and_obj(test_form):  # noqa

    tf = test_form(
        DummyPostData({
            "pdf1:year": "2000"
        }), MagicMock(pdf1=PartialDateDbField(2017, 1, 13)))
    pdf1 = tf.pdf1()

    assert '<option selected value="13">' in pdf1
    assert '<option value="2001">2001</option><option selected value="2000">2000</option>' in pdf1
    assert '<option value="">Month</option><option selected value="1">01</option><option value="2">' in pdf1


def test_orcid_validation(test_form):  # noqa

    orcid_id = StringField("ORCID iD", [
        validate_orcid_id_field,
    ])
    orcid_id.data = "0000-0001-8228-7153"
    validate_orcid_id_field(test_form, orcid_id)

    orcid_id.data = "INVALID FORMAT"
    with pytest.raises(ValueError) as excinfo:
        validate_orcid_id_field(test_form, orcid_id)
    assert f"Invalid ORCID iD {orcid_id.data}. It should be in the form of 'xxxx-xxxx-xxxx-xxxx' where x is a digit." \
           in str(excinfo.value)

    orcid_id.data = "0000-0001-8228-7154"
    with pytest.raises(ValueError) as excinfo:
        validate_orcid_id_field(test_form, orcid_id)
    assert f"Invalid ORCID iD {orcid_id.data} checksum. Make sure you have entered correct ORCID iD." in str(
        excinfo.value)


def test_country_select_field(test_form):  # noqa
    tf = test_form()
    assert tf.csf1.label.text == "Country"
    assert tf.csf2.label.text == "Select Country"


def test_bitmap_multiple_value_field(test_form):  # noqa
    tf = test_form()
    tf.bmvf1.data = 3
    tf.bmvf2.data = (
        1,
        4,
    )
    tf.validate()
    tf.bmvf1.process_data(5)
    tf.bmvf1.process_data([1, 4])



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.authorization_url_v20 import AuthorizationUrlV20  # noqa: F401,E501
from orcid_api_v3.models.items_v20 import ItemsV20  # noqa: F401,E501
from orcid_api_v3.models.source_v20 import SourceV20  # noqa: F401,E501


class NotificationPermissionV20(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'put_code': 'int',
        'notification_type': 'str',
        'authorization_url': 'AuthorizationUrlV20',
        'notification_subject': 'str',
        'notification_intro': 'str',
        'items': 'ItemsV20',
        'created_date': 'datetime',
        'sent_date': 'datetime',
        'read_date': 'datetime',
        'actioned_date': 'datetime',
        'archived_date': 'datetime',
        'source': 'SourceV20'
    }

    attribute_map = {
        'put_code': 'put-code',
        'notification_type': 'notification-type',
        'authorization_url': 'authorization-url',
        'notification_subject': 'notification-subject',
        'notification_intro': 'notification-intro',
        'items': 'items',
        'created_date': 'created-date',
        'sent_date': 'sent-date',
        'read_date': 'read-date',
        'actioned_date': 'actioned-date',
        'archived_date': 'archived-date',
        'source': 'source'
    }

    def __init__(self, put_code=None, notification_type=None, authorization_url=None, notification_subject=None, notification_intro=None, items=None, created_date=None, sent_date=None, read_date=None, actioned_date=None, archived_date=None, source=None):  # noqa: E501
        """NotificationPermissionV20 - a model defined in Swagger"""  # noqa: E501
        self._put_code = None
        self._notification_type = None
        self._authorization_url = None
        self._notification_subject = None
        self._notification_intro = None
        self._items = None
        self._created_date = None
        self._sent_date = None
        self._read_date = None
        self._actioned_date = None
        self._archived_date = None
        self._source = None
        self.discriminator = None
        if put_code is not None:
            self.put_code = put_code
        self.notification_type = notification_type
        self.authorization_url = authorization_url
        if notification_subject is not None:
            self.notification_subject = notification_subject
        if notification_intro is not None:
            self.notification_intro = notification_intro
        self.items = items
        if created_date is not None:
            self.created_date = created_date
        if sent_date is not None:
            self.sent_date = sent_date
        if read_date is not None:
            self.read_date = read_date
        if actioned_date is not None:
            self.actioned_date = actioned_date
        if archived_date is not None:
            self.archived_date = archived_date
        if source is not None:
            self.source = source

    @property
    def put_code(self):
        """Gets the put_code of this NotificationPermissionV20.  # noqa: E501


        :return: The put_code of this NotificationPermissionV20.  # noqa: E501
        :rtype: int
        """
        return self._put_code

    @put_code.setter
    def put_code(self, put_code):
        """Sets the put_code of this NotificationPermissionV20.


        :param put_code: The put_code of this NotificationPermissionV20.  # noqa: E501
        :type: int
        """

        self._put_code = put_code

    @property
    def notification_type(self):
        """Gets the notification_type of this NotificationPermissionV20.  # noqa: E501


        :return: The notification_type of this NotificationPermissionV20.  # noqa: E501
        :rtype: str
        """
        return self._notification_type

    @notification_type.setter
    def notification_type(self, notification_type):
        """Sets the notification_type of this NotificationPermissionV20.


        :param notification_type: The notification_type of this NotificationPermissionV20.  # noqa: E501
        :type: str
        """
        if notification_type is None:
            raise ValueError("Invalid value for `notification_type`, must not be `None`")  # noqa: E501
        allowed_values = ["CUSTOM", "INSTITUTIONAL_CONNECTION", "PERMISSION", "AMENDED", "SERVICE_ANNOUNCEMENT", "ADMINISTRATIVE", "TIP"]  # noqa: E501
        if notification_type not in allowed_values:
            raise ValueError(
                "Invalid value for `notification_type` ({0}), must be one of {1}"  # noqa: E501
                .format(notification_type, allowed_values)
            )

        self._notification_type = notification_type

    @property
    def authorization_url(self):
        """Gets the authorization_url of this NotificationPermissionV20.  # noqa: E501


        :return: The authorization_url of this NotificationPermissionV20.  # noqa: E501
        :rtype: AuthorizationUrlV20
        """
        return self._authorization_url

    @authorization_url.setter
    def authorization_url(self, authorization_url):
        """Sets the authorization_url of this NotificationPermissionV20.


        :param authorization_url: The authorization_url of this NotificationPermissionV20.  # noqa: E501
        :type: AuthorizationUrlV20
        """
        if authorization_url is None:
            raise ValueError("Invalid value for `authorization_url`, must not be `None`")  # noqa: E501

        self._authorization_url = authorization_url

    @property
    def notification_subject(self):
        """Gets the notification_subject of this NotificationPermissionV20.  # noqa: E501


        :return: The notification_subject of this NotificationPermissionV20.  # noqa: E501
        :rtype: str
        """
        return self._notification_subject

    @notification_subject.setter
    def notification_subject(self, notification_subject):
        """Sets the notification_subject of this NotificationPermissionV20.


        :param notification_subject: The notification_subject of this NotificationPermissionV20.  # noqa: E501
        :type: str
        """

        self._notification_subject = notification_subject

    @property
    def notification_intro(self):
        """Gets the notification_intro of this NotificationPermissionV20.  # noqa: E501


        :return: The notification_intro of this NotificationPermissionV20.  # noqa: E501
        :rtype: str
        """
        return self._notification_intro

    @notification_intro.setter
    def notification_intro(self, notification_intro):
        """Sets the notification_intro of this NotificationPermissionV20.


        :param notification_intro: The notification_intro of this NotificationPermissionV20.  # noqa: E501
        :type: str
        """

        self._notification_intro = notification_intro

    @property
    def items(self):
        """Gets the items of this NotificationPermissionV20.  # noqa: E501


        :return: The items of this NotificationPermissionV20.  # noqa: E501
        :rtype: ItemsV20
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this NotificationPermissionV20.


        :param items: The items of this NotificationPermissionV20.  # noqa: E501
        :type: ItemsV20
        """
        if items is None:
            raise ValueError("Invalid value for `items`, must not be `None`")  # noqa: E501

        self._items = items

    @property
    def created_date(self):
        """Gets the created_date of this NotificationPermissionV20.  # noqa: E501


        :return: The created_date of this NotificationPermissionV20.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this NotificationPermissionV20.


        :param created_date: The created_date of this NotificationPermissionV20.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def sent_date(self):
        """Gets the sent_date of this NotificationPermissionV20.  # noqa: E501


        :return: The sent_date of this NotificationPermissionV20.  # noqa: E501
        :rtype: datetime
        """
        return self._sent_date

    @sent_date.setter
    def sent_date(self, sent_date):
        """Sets the sent_date of this NotificationPermissionV20.


        :param sent_date: The sent_date of this NotificationPermissionV20.  # noqa: E501
        :type: datetime
        """

        self._sent_date = sent_date

    @property
    def read_date(self):
        """Gets the read_date of this NotificationPermissionV20.  # noqa: E501


        :return: The read_date of this NotificationPermissionV20.  # noqa: E501
        :rtype: datetime
        """
        return self._read_date

    @read_date.setter
    def read_date(self, read_date):
        """Sets the read_date of this NotificationPermissionV20.


        :param read_date: The read_date of this NotificationPermissionV20.  # noqa: E501
        :type: datetime
        """

        self._read_date = read_date

    @property
    def actioned_date(self):
        """Gets the actioned_date of this NotificationPermissionV20.  # noqa: E501


        :return: The actioned_date of this NotificationPermissionV20.  # noqa: E501
        :rtype: datetime
        """
        return self._actioned_date

    @actioned_date.setter
    def actioned_date(self, actioned_date):
        """Sets the actioned_date of this NotificationPermissionV20.


        :param actioned_date: The actioned_date of this NotificationPermissionV20.  # noqa: E501
        :type: datetime
        """

        self._actioned_date = actioned_date

    @property
    def archived_date(self):
        """Gets the archived_date of this NotificationPermissionV20.  # noqa: E501


        :return: The archived_date of this NotificationPermissionV20.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_date

    @archived_date.setter
    def archived_date(self, archived_date):
        """Sets the archived_date of this NotificationPermissionV20.


        :param archived_date: The archived_date of this NotificationPermissionV20.  # noqa: E501
        :type: datetime
        """

        self._archived_date = archived_date

    @property
    def source(self):
        """Gets the source of this NotificationPermissionV20.  # noqa: E501


        :return: The source of this NotificationPermissionV20.  # noqa: E501
        :rtype: SourceV20
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this NotificationPermissionV20.


        :param source: The source of this NotificationPermissionV20.  # noqa: E501
        :type: SourceV20
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationPermissionV20, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationPermissionV20):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.created_date_v30 import CreatedDateV30  # noqa: F401,E501
from orcid_api_v3.models.credit_name_v30 import CreditNameV30  # noqa: F401,E501
from orcid_api_v3.models.family_name_v30 import FamilyNameV30  # noqa: F401,E501
from orcid_api_v3.models.given_names_v30 import GivenNamesV30  # noqa: F401,E501
from orcid_api_v3.models.last_modified_date_v30 import LastModifiedDateV30  # noqa: F401,E501
from orcid_api_v3.models.source_v30 import SourceV30  # noqa: F401,E501


class NameV30(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date': 'CreatedDateV30',
        'last_modified_date': 'LastModifiedDateV30',
        'given_names': 'GivenNamesV30',
        'family_name': 'FamilyNameV30',
        'credit_name': 'CreditNameV30',
        'source': 'SourceV30',
        'visibility': 'str',
        'path': 'str'
    }

    attribute_map = {
        'created_date': 'created-date',
        'last_modified_date': 'last-modified-date',
        'given_names': 'given-names',
        'family_name': 'family-name',
        'credit_name': 'credit-name',
        'source': 'source',
        'visibility': 'visibility',
        'path': 'path'
    }

    def __init__(self, created_date=None, last_modified_date=None, given_names=None, family_name=None, credit_name=None, source=None, visibility=None, path=None):  # noqa: E501
        """NameV30 - a model defined in Swagger"""  # noqa: E501
        self._created_date = None
        self._last_modified_date = None
        self._given_names = None
        self._family_name = None
        self._credit_name = None
        self._source = None
        self._visibility = None
        self._path = None
        self.discriminator = None
        if created_date is not None:
            self.created_date = created_date
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if given_names is not None:
            self.given_names = given_names
        if family_name is not None:
            self.family_name = family_name
        if credit_name is not None:
            self.credit_name = credit_name
        if source is not None:
            self.source = source
        if visibility is not None:
            self.visibility = visibility
        if path is not None:
            self.path = path

    @property
    def created_date(self):
        """Gets the created_date of this NameV30.  # noqa: E501


        :return: The created_date of this NameV30.  # noqa: E501
        :rtype: CreatedDateV30
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this NameV30.


        :param created_date: The created_date of this NameV30.  # noqa: E501
        :type: CreatedDateV30
        """

        self._created_date = created_date

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this NameV30.  # noqa: E501


        :return: The last_modified_date of this NameV30.  # noqa: E501
        :rtype: LastModifiedDateV30
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this NameV30.


        :param last_modified_date: The last_modified_date of this NameV30.  # noqa: E501
        :type: LastModifiedDateV30
        """

        self._last_modified_date = last_modified_date

    @property
    def given_names(self):
        """Gets the given_names of this NameV30.  # noqa: E501


        :return: The given_names of this NameV30.  # noqa: E501
        :rtype: GivenNamesV30
        """
        return self._given_names

    @given_names.setter
    def given_names(self, given_names):
        """Sets the given_names of this NameV30.


        :param given_names: The given_names of this NameV30.  # noqa: E501
        :type: GivenNamesV30
        """

        self._given_names = given_names

    @property
    def family_name(self):
        """Gets the family_name of this NameV30.  # noqa: E501


        :return: The family_name of this NameV30.  # noqa: E501
        :rtype: FamilyNameV30
        """
        return self._family_name

    @family_name.setter
    def family_name(self, family_name):
        """Sets the family_name of this NameV30.


        :param family_name: The family_name of this NameV30.  # noqa: E501
        :type: FamilyNameV30
        """

        self._family_name = family_name

    @property
    def credit_name(self):
        """Gets the credit_name of this NameV30.  # noqa: E501


        :return: The credit_name of this NameV30.  # noqa: E501
        :rtype: CreditNameV30
        """
        return self._credit_name

    @credit_name.setter
    def credit_name(self, credit_name):
        """Sets the credit_name of this NameV30.


        :param credit_name: The credit_name of this NameV30.  # noqa: E501
        :type: CreditNameV30
        """

        self._credit_name = credit_name

    @property
    def source(self):
        """Gets the source of this NameV30.  # noqa: E501


        :return: The source of this NameV30.  # noqa: E501
        :rtype: SourceV30
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this NameV30.


        :param source: The source of this NameV30.  # noqa: E501
        :type: SourceV30
        """

        self._source = source

    @property
    def visibility(self):
        """Gets the visibility of this NameV30.  # noqa: E501


        :return: The visibility of this NameV30.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this NameV30.


        :param visibility: The visibility of this NameV30.  # noqa: E501
        :type: str
        """
        allowed_values = ["LIMITED", "REGISTERED_ONLY", "PUBLIC", "PRIVATE"]  # noqa: E501
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"  # noqa: E501
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    @property
    def path(self):
        """Gets the path of this NameV30.  # noqa: E501


        :return: The path of this NameV30.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this NameV30.


        :param path: The path of this NameV30.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NameV30, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NameV30):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CountryV30Rc1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'value': 'str'
    }

    attribute_map = {
        'value': 'value'
    }

    def __init__(self, value=None):  # noqa: E501
        """CountryV30Rc1 - a model defined in Swagger"""  # noqa: E501
        self._value = None
        self.discriminator = None
        if value is not None:
            self.value = value

    @property
    def value(self):
        """Gets the value of this CountryV30Rc1.  # noqa: E501


        :return: The value of this CountryV30Rc1.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this CountryV30Rc1.


        :param value: The value of this CountryV30Rc1.  # noqa: E501
        :type: str
        """
        allowed_values = ["AF", "AX", "AL", "DZ", "AS", "AD", "AO", "AI", "AQ", "AG", "AR", "AM", "AW", "AU", "AT", "AZ", "BS", "BH", "BD", "BB", "BY", "BE", "BZ", "BJ", "BM", "BT", "BO", "BQ", "BA", "BW", "BV", "BR", "IO", "BN", "BG", "BF", "BI", "KH", "CM", "CA", "CV", "KY", "CF", "TD", "CL", "CN", "CX", "CC", "CO", "KM", "CG", "CD", "CK", "CR", "CI", "HR", "CU", "CW", "CY", "CZ", "DK", "DJ", "DM", "DO", "EC", "EG", "SV", "GQ", "ER", "EE", "ET", "FK", "FO", "FJ", "FI", "FR", "GF", "PF", "TF", "GA", "GM", "GE", "DE", "GH", "GI", "GR", "GL", "GD", "GP", "GU", "GT", "GG", "GN", "GW", "GY", "HT", "HM", "VA", "HN", "HK", "HU", "IS", "IN", "ID", "IR", "IQ", "IE", "IM", "IL", "IT", "JM", "JP", "JE", "JO", "KZ", "KE", "KI", "KP", "KR", "KW", "KG", "LA", "LV", "LB", "LS", "LR", "LY", "LI", "LT", "LU", "MO", "MK", "MG", "MW", "MY", "MV", "ML", "MT", "MH", "MQ", "MR", "MU", "YT", "MX", "FM", "MD", "MC", "MN", "ME", "MS", "MA", "MZ", "MM", "NA", "NR", "NP", "NL", "NC", "NZ", "NI", "NE", "NG", "NU", "NF", "MP", "NO", "OM", "PK", "PW", "PS", "PA", "PG", "PY", "PE", "PH", "PN", "PL", "PT", "PR", "QA", "RE", "RO", "RU", "RW", "BL", "SH", "KN", "LC", "MF", "PM", "VC", "WS", "SM", "ST", "SA", "SN", "RS", "SC", "SL", "SG", "SX", "SK", "SI", "SB", "SO", "ZA", "GS", "SS", "ES", "LK", "SD", "SR", "SJ", "SZ", "SE", "CH", "SY", "TJ", "TZ", "TH", "TL", "TG", "TK", "TO", "TT", "TN", "TR", "TM", "TC", "TV", "UG", "UA", "AE", "GB", "US", "UM", "UY", "UZ", "VU", "VE", "VN", "VG", "VI", "WF", "EH", "YE", "ZM", "ZW", "TW", "XK"]  # noqa: E501
        if value not in allowed_values:
            raise ValueError(
                "Invalid value for `value` ({0}), must be one of {1}"  # noqa: E501
                .format(value, allowed_values)
            )

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CountryV30Rc1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CountryV30Rc1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.created_date_v30_rc2 import CreatedDateV30Rc2  # noqa: F401,E501
from orcid_api_v3.models.last_modified_date_v30_rc2 import LastModifiedDateV30Rc2  # noqa: F401,E501
from orcid_api_v3.models.source_v30_rc2 import SourceV30Rc2  # noqa: F401,E501


class KeywordV30Rc2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date': 'CreatedDateV30Rc2',
        'last_modified_date': 'LastModifiedDateV30Rc2',
        'source': 'SourceV30Rc2',
        'content': 'str',
        'visibility': 'str',
        'path': 'str',
        'put_code': 'int',
        'display_index': 'int'
    }

    attribute_map = {
        'created_date': 'created-date',
        'last_modified_date': 'last-modified-date',
        'source': 'source',
        'content': 'content',
        'visibility': 'visibility',
        'path': 'path',
        'put_code': 'put-code',
        'display_index': 'display-index'
    }

    def __init__(self, created_date=None, last_modified_date=None, source=None, content=None, visibility=None, path=None, put_code=None, display_index=None):  # noqa: E501
        """KeywordV30Rc2 - a model defined in Swagger"""  # noqa: E501
        self._created_date = None
        self._last_modified_date = None
        self._source = None
        self._content = None
        self._visibility = None
        self._path = None
        self._put_code = None
        self._display_index = None
        self.discriminator = None
        if created_date is not None:
            self.created_date = created_date
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if source is not None:
            self.source = source
        if content is not None:
            self.content = content
        if visibility is not None:
            self.visibility = visibility
        if path is not None:
            self.path = path
        if put_code is not None:
            self.put_code = put_code
        if display_index is not None:
            self.display_index = display_index

    @property
    def created_date(self):
        """Gets the created_date of this KeywordV30Rc2.  # noqa: E501


        :return: The created_date of this KeywordV30Rc2.  # noqa: E501
        :rtype: CreatedDateV30Rc2
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this KeywordV30Rc2.


        :param created_date: The created_date of this KeywordV30Rc2.  # noqa: E501
        :type: CreatedDateV30Rc2
        """

        self._created_date = created_date

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this KeywordV30Rc2.  # noqa: E501


        :return: The last_modified_date of this KeywordV30Rc2.  # noqa: E501
        :rtype: LastModifiedDateV30Rc2
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this KeywordV30Rc2.


        :param last_modified_date: The last_modified_date of this KeywordV30Rc2.  # noqa: E501
        :type: LastModifiedDateV30Rc2
        """

        self._last_modified_date = last_modified_date

    @property
    def source(self):
        """Gets the source of this KeywordV30Rc2.  # noqa: E501


        :return: The source of this KeywordV30Rc2.  # noqa: E501
        :rtype: SourceV30Rc2
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this KeywordV30Rc2.


        :param source: The source of this KeywordV30Rc2.  # noqa: E501
        :type: SourceV30Rc2
        """

        self._source = source

    @property
    def content(self):
        """Gets the content of this KeywordV30Rc2.  # noqa: E501


        :return: The content of this KeywordV30Rc2.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this KeywordV30Rc2.


        :param content: The content of this KeywordV30Rc2.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def visibility(self):
        """Gets the visibility of this KeywordV30Rc2.  # noqa: E501


        :return: The visibility of this KeywordV30Rc2.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this KeywordV30Rc2.


        :param visibility: The visibility of this KeywordV30Rc2.  # noqa: E501
        :type: str
        """
        allowed_values = ["LIMITED", "REGISTERED_ONLY", "PUBLIC", "PRIVATE"]  # noqa: E501
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"  # noqa: E501
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    @property
    def path(self):
        """Gets the path of this KeywordV30Rc2.  # noqa: E501


        :return: The path of this KeywordV30Rc2.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this KeywordV30Rc2.


        :param path: The path of this KeywordV30Rc2.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def put_code(self):
        """Gets the put_code of this KeywordV30Rc2.  # noqa: E501


        :return: The put_code of this KeywordV30Rc2.  # noqa: E501
        :rtype: int
        """
        return self._put_code

    @put_code.setter
    def put_code(self, put_code):
        """Sets the put_code of this KeywordV30Rc2.


        :param put_code: The put_code of this KeywordV30Rc2.  # noqa: E501
        :type: int
        """

        self._put_code = put_code

    @property
    def display_index(self):
        """Gets the display_index of this KeywordV30Rc2.  # noqa: E501


        :return: The display_index of this KeywordV30Rc2.  # noqa: E501
        :rtype: int
        """
        return self._display_index

    @display_index.setter
    def display_index(self, display_index):
        """Sets the display_index of this KeywordV30Rc2.


        :param display_index: The display_index of this KeywordV30Rc2.  # noqa: E501
        :type: int
        """

        self._display_index = display_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KeywordV30Rc2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordV30Rc2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
